# Browser Interface

> **Important:** this package is in early development. It is not ready for production! **Do not use it**.

[WebExtensions](https://developer.mozilla.org/en-US/Add-ons/WebExtensions) allows people to develop browser extensions for multiple browsers. Unfortunately, the methods and syntaxes are not exactly the same in every browser, so that requires some tweaking. This package aims to solve this problem by providing a single syntax for all browsers. It uses the methods and syntax described on the [MDN website](https://developer.mozilla.org/en-US/Add-ons/WebExtensions), and it is compatible with Google Chrome and Mozilla Firefox. Not tested yet in Microsoft Edge.

## Installation

Using npm:

```
npm install --save browser-interface
```

In Node.js:

```javascript
import BrowserInterface from "browser-interface";

// Create a driver and pass it the window Object
const driver = new BrowserInterface(window);

// Use it in all browsers
driver.webRequest.onBeforeRequest.addListener(
  req => {
    console.log(req);
  },
  { urls: ["<all_urls>"] }
);
```

## API coverage

This project is still in progress. Here are the different WebExtensions APIs supported at this time.

### webRequest

| Property                                                                                                                   | Status   | Chrome             | Firefox            | Edge            |
| -------------------------------------------------------------------------------------------------------------------------- | -------- | ------------------ | ------------------ | --------------- |
| [onBeforeRedirect](https://developer.mozilla.org/docs/Mozilla/Add-ons/WebExtensions/API/webRequest/onBeforeRedirect)       | Complete | :grey_question:    | :grey_question:    | :grey_question: |
| [onBeforeRequest](https://developer.mozilla.org/docs/Mozilla/Add-ons/WebExtensions/API/webRequest/onBeforeRequest)         | Complete | :heavy_check_mark: | :heavy_check_mark: | :grey_question: |
| [onBeforeSendHeaders](https://developer.mozilla.org/docs/Mozilla/Add-ons/WebExtensions/API/webRequest/onBeforeSendHeaders) | Complete | :heavy_check_mark: | :heavy_check_mark: | :grey_question: |
| [onCompleted](https://developer.mozilla.org/docs/Mozilla/Add-ons/WebExtensions/API/webRequest/onCompleted)                 | Complete | :heavy_check_mark: | :heavy_check_mark: | :grey_question: |
| [onErrorOccurred](https://developer.mozilla.org/docs/Mozilla/Add-ons/WebExtensions/API/webRequest/onErrorOccurred)         | Complete | :grey_question:    | :grey_question:    | :grey_question: |
| [onHeadersReceived](https://developer.mozilla.org/docs/Mozilla/Add-ons/WebExtensions/API/webRequest/onHeadersReceived)     | Complete | :heavy_check_mark: | :heavy_check_mark: | :grey_question: |
| [onResponseStarted](https://developer.mozilla.org/docs/Mozilla/Add-ons/WebExtensions/API/webRequest/onResponseStarted)     | Complete | :heavy_check_mark: | :heavy_check_mark: | :grey_question: |
| [onSendHeaders](https://developer.mozilla.org/docs/Mozilla/Add-ons/WebExtensions/API/webRequest/onSendHeaders)             | Complete | :heavy_check_mark: | :heavy_check_mark: | :grey_question: |

### tabs

| Property                                                                                                 | Status   | Chrome             | Firefox            | Edge                     |
| -------------------------------------------------------------------------------------------------------- | -------- | ------------------ | ------------------ | ------------------------ |
| [onActivated](https://developer.mozilla.org/docs/Mozilla/Add-ons/WebExtensions/API/tabs/onActivated)     | Complete | :heavy_check_mark: | :heavy_check_mark: | :grey_question:          |
| [onAttached](https://developer.mozilla.org/docs/Mozilla/Add-ons/WebExtensions/API/tabs/onAttached)       | Complete | :heavy_check_mark: | :heavy_check_mark: | :grey_question:          |
| [onCreated](https://developer.mozilla.org/docs/Mozilla/Add-ons/WebExtensions/API/tabs/onCreated)         | Complete | :heavy_check_mark: | :heavy_check_mark: | :grey_question:          |
| [onDetached](https://developer.mozilla.org/docs/Mozilla/Add-ons/WebExtensions/API/tabs/onDetached)       | Complete | :heavy_check_mark: | :heavy_check_mark: | :grey_question:          |
| [onHighlighted](https://developer.mozilla.org/docs/Mozilla/Add-ons/WebExtensions/API/tabs/onHighlighted) | Complete | :heavy_check_mark: | :heavy_check_mark: | :heavy_multiplication_x: |
| [onMoved](https://developer.mozilla.org/docs/Mozilla/Add-ons/WebExtensions/API/tabs/onMoved)             | Complete | :heavy_check_mark: | :heavy_check_mark: | :heavy_multiplication_x: |
| [onRemoved](https://developer.mozilla.org/docs/Mozilla/Add-ons/WebExtensions/API/tabs/onRemoved)         | Complete | :heavy_check_mark: | :heavy_check_mark: | :grey_question:          |
| [onUpdated](https://developer.mozilla.org/docs/Mozilla/Add-ons/WebExtensions/API/tabs/onUpdated)         | Complete | :heavy_check_mark: | :heavy_check_mark: | :grey_question:          |
| [sendMessage](https://developer.mozilla.org/docs/Mozilla/Add-ons/WebExtensions/API/tabs/sendMessage)     | Complete | :grey_question:    | :grey_question:    | :grey_question:          |
| [query](https://developer.mozilla.org/docs/Mozilla/Add-ons/WebExtensions/API/tabs/query)                 | Complete | :heavy_check_mark: | :grey_question:    | :grey_question:          |
| [create](https://developer.mozilla.org/docs/Mozilla/Add-ons/WebExtensions/API/tabs/create)               | Complete | :grey_question:    | :grey_question:    | :grey_question:          |
| [remove](https://developer.mozilla.org/docs/Mozilla/Add-ons/WebExtensions/API/tabs/remove)               | Complete | :grey_question:    | :grey_question:    | :grey_question:          |
| [update](https://developer.mozilla.org/docs/Mozilla/Add-ons/WebExtensions/API/tabs/update)               | Complete | :grey_question:    | :grey_question:    | :grey_question:          |
| [get](https://developer.mozilla.org/en-US/Add-ons/WebExtensions/API/tabs/get)                            | Complete | :grey_question:    | :grey_question:    | :grey_question:          |
| [getCurrent](https://developer.mozilla.org/docs/Mozilla/Add-ons/WebExtensions/API/tabs/getCurrent)       | Complete | :grey_question:    | :grey_question:    | :grey_question:          |

### storage

| Property                                                                             | Status   | Chrome             | Firefox         | Edge            |
| ------------------------------------------------------------------------------------ | -------- | ------------------ | --------------- | --------------- |
| [sync](https://developer.mozilla.org/en-US/Add-ons/WebExtensions/API/storage/sync)   | Complete | :heavy_check_mark: | :grey_question: | :grey_question: |
| [local](https://developer.mozilla.org/en-US/Add-ons/WebExtensions/API/storage/local) | Complete | :heavy_check_mark: | :grey_question: | :grey_question: |

### browserAction

| Property                                                                                                | Status   | Chrome             | Firefox         | Edge            |
| ------------------------------------------------------------------------------------------------------- | -------- | ------------------ | --------------- | --------------- |
| [enable](https://developer.mozilla.org/docs/Mozilla/Add-ons/WebExtensions/API/browserAction/enable)     | Complete | :grey_question:    | :grey_question: | :grey_question: |
| [disable](https://developer.mozilla.org/docs/Mozilla/Add-ons/WebExtensions/API/browserAction/disable)   | Complete | :grey_question:    | :grey_question: | :grey_question: |
| [setIcon](https://developer.mozilla.org/docs/Mozilla/Add-ons/WebExtensions/API/browserAction/setIcon)   | Complete | :heavy_check_mark: | :grey_question: | :grey_question: |
| [setPopup](https://developer.mozilla.org/docs/Mozilla/Add-ons/WebExtensions/API/browserAction/setPopup) | Complete | :grey_question:    | :grey_question: | :grey_question: |
| [setTitle](https://developer.mozilla.org/docs/Mozilla/Add-ons/WebExtensions/API/browserAction/setTitle) | Complete | :grey_question:    | :grey_question: | :grey_question: |

### runtime

| Property                                                                                                     | Status   | Chrome             | Firefox         | Edge            |
| ------------------------------------------------------------------------------------------------------------ | -------- | ------------------ | --------------- | --------------- |
| [getBackgroundPage](https://developer.mozilla.org/en-US/Add-ons/WebExtensions/API/runtime/getBackgroundPage) | Complete | :heavy_check_mark: | :grey_question: | :grey_question: |
| [onMessage](https://developer.mozilla.org/en-US/Add-ons/WebExtensions/API/runtime/onMessage)                 | Complete | :heavy_check_mark: | :grey_question: | :grey_question: |
| [sendMessage](https://developer.mozilla.org/en-US/Add-ons/WebExtensions/API/runtime/sendMessage)             | Complete | :heavy_check_mark: | :grey_question: | :grey_question: |
