/*
 * runtime APIs
 * ------------
 * Chrome's `chrome.runtime` works the same as WebExtentions,
 * but its methods expect callbacks and don't return promises.
 * 
 * See: https://developer.mozilla.org/en-US/Add-ons/WebExtensions/Browser_support_for_JavaScript_APIs#runtime
 */

const Runtime = browser => ({
  // https://developer.mozilla.org/en-US/Add-ons/WebExtensions/API/runtime/getBackgroundPage
  getBackgroundPage() {
    return new Promise(res => browser.runtime.getBackgroundPage(res));
  },
  // https://developer.mozilla.org/en-US/Add-ons/WebExtensions/API/runtime/onMessage
  onMessage: browser.runtime.onMessage,
  // https://developer.mozilla.org/en-US/Add-ons/WebExtensions/API/runtime/sendMessage
  sendMessage(extensionId, message, options) {
    return new Promise(res =>
      browser.runtime.sendMessage(extensionId, message, options, res)
    );
  }
});

export default Runtime;
